@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator;
-$Games::ABC_Path::Generator::VERSION = '0.4.0';
+$Games::ABC_Path::Generator::VERSION = '0.4.1';
 use 5.006;
 
 use strict;
@@ -333,7 +333,7 @@ Games::ABC_Path::Generator - a generator for ABC Path puzzle games.
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
@@ -359,7 +359,7 @@ layout with different clues for every random number generator seed.
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SUBROUTINES/METHODS
 
@@ -481,7 +481,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/games-abc_path-generator/issues>
+L<https://github.com/shlomif/abc-path/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -590,7 +590,7 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/games-abc_path-generator>
+L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
