@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator::Coord;
-$Games::ABC_Path::Generator::Coord::VERSION = '0.4.0';
+$Games::ABC_Path::Generator::Coord::VERSION = '0.4.1';
 use 5.006;
 
 use strict;
@@ -33,7 +33,7 @@ Games::ABC_Path::Generator::Coord - a coordinate class.
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
@@ -41,7 +41,7 @@ B<For internal use.>.
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 AUTHOR
 
@@ -126,7 +126,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/games-abc_path-generator/issues>
+L<https://github.com/shlomif/abc-path/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -235,7 +235,7 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/games-abc_path-generator>
+L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
